var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { useCallback, useReducer, useRef } from 'react';
import { requestError, requestInit, requestSuccess } from './action-creators';
import { httpRequestReducer, initialState } from './state-reducer';
import fastCompare from 'react-fast-compare';
import { useHttpClient } from '../client';
import { useCompareCallback, useCompareMemo, useCompareEffect } from '../shared';
export var useHttpRequest = function (params) {
    /**
     * Grabs the "request" function from the http client.
     */
    var _a = useHttpClient(), httpClientAbortableRequest = _a.abortableRequest, httpClientRequest = _a.request;
    // The state of the request.
    var _b = useReducer(httpRequestReducer, initialState(params.initialData)), state = _b[0], dispatch = _b[1];
    /**
     * A ref telling whether the component is currently mounted or not.
     */
    var isMounted = useRef(false);
    /**
     * Safely dispatches an action by first checking the mounting state of the component.
     */
    var safelyDispatch = useCallback(function (action) {
        if (isMounted.current) {
            dispatch(action);
        }
    }, [dispatch]);
    /**
     * Gets the http params needed to perform the request using the http client related method.
     */
    var performHttpRequestParams = useCompareMemo(function () { return ({
        baseUrlOverride: params.baseUrlOverride,
        parser: params.parser,
        relativeUrl: params.relativeUrl,
        requestOptions: params.requestOptions,
        context: params.context,
    }); }, [params], fastCompare);
    /**
     * Merges the overrided http params into the source one.
     */
    var mergeParams = useCallback(function (source, override) {
        var _a, _b, _c, _d, _e, _f, _g;
        var baseUrlOverride = override.baseUrlOverride, parser = override.parser, relativeUrl = override.relativeUrl, requestOptions = override.requestOptions, context = override.context;
        return {
            baseUrlOverride: baseUrlOverride || source.baseUrlOverride,
            parser: parser || source.parser,
            relativeUrl: relativeUrl || source.relativeUrl,
            context: context || source.context,
            requestOptions: {
                body: (requestOptions === null || requestOptions === void 0 ? void 0 : requestOptions.body) || ((_a = source.requestOptions) === null || _a === void 0 ? void 0 : _a.body),
                credentials: (requestOptions === null || requestOptions === void 0 ? void 0 : requestOptions.credentials) || ((_b = source.requestOptions) === null || _b === void 0 ? void 0 : _b.credentials),
                headers: __assign(__assign({}, (((_c = source.requestOptions) === null || _c === void 0 ? void 0 : _c.headers) || {})), ((requestOptions === null || requestOptions === void 0 ? void 0 : requestOptions.headers) || {})),
                maxAge: (requestOptions === null || requestOptions === void 0 ? void 0 : requestOptions.maxAge) || ((_d = source.requestOptions) === null || _d === void 0 ? void 0 : _d.maxAge),
                method: (requestOptions === null || requestOptions === void 0 ? void 0 : requestOptions.method) || ((_e = source.requestOptions) === null || _e === void 0 ? void 0 : _e.method),
                queryParams: (requestOptions === null || requestOptions === void 0 ? void 0 : requestOptions.queryParams) || ((_f = source.requestOptions) === null || _f === void 0 ? void 0 : _f.queryParams),
                signal: (requestOptions === null || requestOptions === void 0 ? void 0 : requestOptions.signal) || ((_g = source.requestOptions) === null || _g === void 0 ? void 0 : _g.signal),
            },
        };
    }, []);
    /**
     * Performs the http request allowing to abort it.
     */
    var abortableRequest = useCompareCallback(function (paramsOverride) {
        safelyDispatch(requestInit());
        var mergedParams = paramsOverride
            ? mergeParams(performHttpRequestParams, paramsOverride)
            : performHttpRequestParams;
        var _a = httpClientAbortableRequest(mergedParams), reqResult = _a[0], abortController = _a[1];
        // Listen request to be successfully resolved or reject and
        // update the state accordingly.
        reqResult
            .then(function (response) {
            safelyDispatch(requestSuccess(response));
        })
            .catch(function (error) {
            safelyDispatch(requestError(error));
        });
        return { reqResult: reqResult, abortController: abortController };
    }, [httpClientAbortableRequest, performHttpRequestParams, safelyDispatch], fastCompare);
    /**
     * Performs the http request.
     */
    var request = useCompareCallback(function (paramsOverride) {
        safelyDispatch(requestInit());
        var mergedParams = paramsOverride
            ? mergeParams(performHttpRequestParams, paramsOverride)
            : performHttpRequestParams;
        var reqResult = httpClientRequest(mergedParams);
        // Listen request to be successfully resolved or reject and
        // update the state accordingly.
        reqResult
            .then(function (response) {
            safelyDispatch(requestSuccess(response));
        })
            .catch(function (error) {
            safelyDispatch(requestError(error));
        });
        return reqResult;
    }, [httpClientRequest, performHttpRequestParams, safelyDispatch], fastCompare);
    /**
     * Keeps track of the mounting state of the component.
     */
    useCompareEffect(function () {
        isMounted.current = true;
        var fetchOnBootstrap = params.fetchOnBootstrap;
        if (fetchOnBootstrap) {
            request();
        }
        return function () {
            isMounted.current = false;
        };
    }, [params, request], fastCompare);
    return [state, abortableRequest, request];
};
